diff src/ex_docmd.c @ 29938:935717599faa v9.0.0307

patch 9.0.0307: :echomsg doesn't work properly with cmdheight=0 Commit: https://github.com/vim/vim/commit/134b86553c12c46e0ae7d534f6fe65e8ba2d50bc Author: Bram Moolenaar <Bram@vim.org> Date: Sun Aug 28 21:36:43 2022 +0100 patch 9.0.0307: :echomsg doesn't work properly with cmdheight=0 Problem: :echomsg doesn't work properly with cmdheight=0. Solution: Improve scrolling and displaying.
author Bram Moolenaar <Bram@vim.org>
date Sun, 28 Aug 2022 22:45:03 +0200
parents 31c598083364
children 4fcf816aa806
line wrap: on
line diff
--- a/src/ex_docmd.c
+++ b/src/ex_docmd.c
@@ -8370,9 +8370,14 @@ ex_redraw(exarg_T *eap)
     // After drawing the statusline screen_attr may still be set.
     screen_stop_highlight();
 
-    // Reset msg_didout, so that a message that's there is overwritten.
-    msg_didout = FALSE;
-    msg_col = 0;
+#ifdef HAS_MESSAGE_WINDOW
+    if (!use_message_window())  // append messages in the message window
+#endif
+    {
+	// Reset msg_didout, so that a message that's there is overwritten.
+	msg_didout = FALSE;
+	msg_col = 0;
+    }
 
     // No need to wait after an intentional redraw.
     need_wait_return = FALSE;